==> unit-1.1.1-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTaskHistoryEntryTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTaskHistoryEntryTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _124_1_01281209709 _124_1_01281209709;
	public TaskHistoryEntryTemplate._124_1_01281209709. Date date;
	public TaskHistoryEntryTemplate._124_1_01281209709. Author author;
	public Title title;
	public Subtitle subtitle;
	public LinksBlock linksBlock;

    public AbstractTaskHistoryEntryTemplate(B box) {
        super(box);
        id("taskHistoryEntryTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_124_1_01281209709 == null) _124_1_01281209709 = register(new _124_1_01281209709(box()).<_124_1_01281209709>id("a_1402430055").owner(AbstractTaskHistoryEntryTemplate.this));
		if (_124_1_01281209709 != null) date = _124_1_01281209709.date;
		if (_124_1_01281209709 != null) author = _124_1_01281209709.author;
		if (title == null) title = register(new Title(box()).<Title>id("a_1405051979").owner(AbstractTaskHistoryEntryTemplate.this));
		if (subtitle == null) subtitle = register(new Subtitle(box()).<Subtitle>id("a657357211").owner(AbstractTaskHistoryEntryTemplate.this));
		if (linksBlock == null) linksBlock = register(new LinksBlock((UnitBox)box()).<LinksBlock>id("a_2063251177").owner(AbstractTaskHistoryEntryTemplate.this));
	}

    @Override
    public void remove() {
        super.remove();
	    if (_124_1_01281209709 != null) _124_1_01281209709.unregister();
	    if (title != null) title.unregister();
	    if (subtitle != null) subtitle.unregister();
	    if (linksBlock != null) linksBlock.unregister();
	}

	public class _124_1_01281209709 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskHistoryEntryTemplate._124_1_01281209709. Date date;
		public TaskHistoryEntryTemplate._124_1_01281209709. Author author;

		public _124_1_01281209709(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (date == null) date = register(new Date(box()).<Date>id("a300260542").owner(AbstractTaskHistoryEntryTemplate.this));
			if (author == null) author = register(new Author(box()).<Author>id("a720161435").owner(AbstractTaskHistoryEntryTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (date != null) date.unregister();
			if (author != null) author.unregister();
		}

		public class Date extends io.intino.alexandria.ui.displays.components.Date<io.intino.alexandria.ui.displays.notifiers.DateNotifier, B>  {

			public Date(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class Author extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Author(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class Title extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public Title(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
	}

	public class Subtitle extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public Subtitle(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
	}

	public class LinksBlock extends io.intino.alexandria.ui.displays.components.Multiple<UnitBox,TaskHistoryEntryLinkTemplate, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UnitBox,TaskHistoryEntryLinkTemplate, java.lang.Void> {

		public LinksBlock(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}

		@Override
		public TaskHistoryEntryLinkTemplate add(java.lang.Void value) {
			TaskHistoryEntryLinkTemplate child = new TaskHistoryEntryLinkTemplate(box());
			child.id(java.util.UUID.randomUUID().toString());
			add(child, "linksBlock");
		    notifyAdd(child);
			return child;
		}
		@Override
		public void remove(TaskHistoryEntryLinkTemplate child) {
			removeChild(child, "linksBlock");
		}
		public void clear() {
		    super.clear("linksBlock");
		}
	}
}

==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTaskHistoryEntryTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTaskHistoryEntryTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _136_1_189669429 _136_1_189669429;
	public TaskHistoryEntryTemplate._136_1_189669429. Date date;
	public TaskHistoryEntryTemplate._136_1_189669429. Author author;
	public Title title;
	public Subtitle subtitle;
	public LinksBlock linksBlock;

    public AbstractTaskHistoryEntryTemplate(B box) {
        super(box);
        id("taskHistoryEntryTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_136_1_189669429 == null) _136_1_189669429 = register(new _136_1_189669429(box()).<_136_1_189669429>id("a_1824171233").owner(AbstractTaskHistoryEntryTemplate.this));
		if (_136_1_189669429 != null) date = _136_1_189669429.date;
		if (_136_1_189669429 != null) author = _136_1_189669429.author;
		if (title == null) title = register(new Title(box()).<Title>id("a_1405051979").owner(AbstractTaskHistoryEntryTemplate.this));
		if (subtitle == null) subtitle = register(new Subtitle(box()).<Subtitle>id("a657357211").owner(AbstractTaskHistoryEntryTemplate.this));
		if (linksBlock == null) linksBlock = register(new LinksBlock((UnitBox)box()).<LinksBlock>id("a_2063251177").owner(AbstractTaskHistoryEntryTemplate.this));
	}

    @Override
    public void remove() {
        super.remove();
	    if (_136_1_189669429 != null) _136_1_189669429.unregister();
	    if (title != null) title.unregister();
	    if (subtitle != null) subtitle.unregister();
	    if (linksBlock != null) linksBlock.unregister();
	}

	public class _136_1_189669429 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskHistoryEntryTemplate._136_1_189669429. Date date;
		public TaskHistoryEntryTemplate._136_1_189669429. Author author;

		public _136_1_189669429(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (date == null) date = register(new Date(box()).<Date>id("a1978426749").owner(AbstractTaskHistoryEntryTemplate.this));
			if (author == null) author = register(new Author(box()).<Author>id("a_1469816934").owner(AbstractTaskHistoryEntryTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (date != null) date.unregister();
			if (author != null) author.unregister();
		}

		public class Date extends io.intino.alexandria.ui.displays.components.Date<io.intino.alexandria.ui.displays.notifiers.DateNotifier, B>  {

			public Date(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class Author extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Author(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class Title extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public Title(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
	}

	public class Subtitle extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public Subtitle(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
	}

	public class LinksBlock extends io.intino.alexandria.ui.displays.components.Multiple<UnitBox,TaskHistoryEntryLinkTemplate, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UnitBox,TaskHistoryEntryLinkTemplate, java.lang.Void> {

		public LinksBlock(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}

		@Override
		public TaskHistoryEntryLinkTemplate add(java.lang.Void value) {
			TaskHistoryEntryLinkTemplate child = new TaskHistoryEntryLinkTemplate(box());
			child.id(java.util.UUID.randomUUID().toString());
			add(child, "linksBlock");
		    notifyAdd(child);
			return child;
		}
		@Override
		public void remove(TaskHistoryEntryLinkTemplate child) {
			removeChild(child, "linksBlock");
		}
		public void clear() {
		    super.clear("linksBlock");
		}
	}
}
